@@ -36,10 +36,10 @@ import os
 
 import rospkg
 
+search_path = os.path.abspath(os.path.join(os.path.dirname(__file__), 'catkin_package_tests'))
+
 
 def test_find_packages():
-    search_path = os.path.abspath(os.path.join(os.path.dirname(__file__), 'catkin_package_tests'))
-
     manager = rospkg.rospack.ManifestManager(rospkg.common.MANIFEST_FILE, ros_paths=[search_path])
     # for backward compatibility a wet package which is not a metapackage is found when searching for MANIFEST_FILE
     assert(len(manager.list()) == 1)
@@ -51,3 +51,19 @@ def test_find_packages():
         assert(pkg_name == 'foo')
         path = manager.get_path(pkg_name)
         assert(path == os.path.join(search_path, 'p1', 'foo'))
+
+
+def test_get_manifest():
+    manager = rospkg.rospack.ManifestManager(rospkg.common.MANIFEST_FILE, ros_paths=[search_path])
+    manif = manager.get_manifest("foo")
+    assert(manif.type == "package")
+
+
+def test_licenses():
+    rospack = rospkg.rospack.RosPack(ros_paths=[search_path])
+    licenses_list = ["BSD", "LGPL"]
+    manif = rospack.get_manifest("foo")
+    assert(manif.license == ", ".join(licenses_list))
+    assert(len(manif.licenses) == 2)
+    for l in manif.licenses:
+        assert(l in licenses_list)
